==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/Messaging.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.messaging;
namespace com.db4o.test {

   public class Messaging : MessageRecipient {
      
      public Messaging() : base() {
      }
      static internal String MSG = "hibabe";
      private Object lastMessage;
      internal String messageString;
      
      public void test() {
         if (Tester.isClientServer()) {
            Tester.server().ext().configure().setMessageRecipient(this);
            MessageSender sender1 = Tester.objectContainer().configure().getMessageSender();
            this.messageString = MSG;
            sender1.send(this);
            Thread.sleep(100);
            Tester.ensure(lastMessage is Messaging);
            Messaging received1 = (Messaging)lastMessage;
            Tester.ensure(received1.messageString.Equals(MSG));
         }
      }
      
      public void processMessage(ObjectContainer con, Object message) {
         lastMessage = message;
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/Messaging.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.messaging;
namespace com.db4o.test {

   public class Messaging : MessageRecipient {
      
      public Messaging() : base() {
      }
      static internal String MSG = "hibabe";
      private Object lastMessage;
      internal String messageString;
      
      public void Test() {
         if (Tester.IsClientServer()) {
            Tester.Server().Ext().Configure().SetMessageRecipient(this);
            MessageSender sender1 = Tester.ObjectContainer().Configure().GetMessageSender();
            this.messageString = MSG;
            sender1.Send(this);
            Thread.Sleep(100);
            Tester.Ensure(lastMessage is Messaging);
            Messaging received1 = (Messaging)lastMessage;
            Tester.Ensure(received1.messageString.Equals(MSG));
         }
      }
      
      public void ProcessMessage(ObjectContainer con, Object message) {
         lastMessage = message;
      }
   }
}
